@@ -1,5 +1,4 @@
 from olea.data.dso import DatasetSubmissionObject
-from olea.data.cold import COLDSubmissionObject
 from olea.utils.analysis_tools import get_metrics, get_examples
 from olea.utils.analysis_tools import get_plotting_info_from_col
 from olea.viz.viz import plot_bar_graph
@@ -9,7 +8,7 @@ class COLDAnalysis(object) :
     
         
     @classmethod
-    def _run_analysis_on_functionality(cls,submission:COLDSubmissionObject, on:str,plot, show_examples) :
+    def _run_analysis_on_functionality(cls,submission:DatasetSubmissionObject, on:str,plot, show_examples,savePlotToFile) :
         """helper function for running analysis on a specific column. Returns two dataframes. plot_info corresponds to 
             information that is plotted, number of offensive/non offensive instances for each category in "on" as well as
             accuracy of model. Metrics returns the classification report for each category specified on "on"
@@ -19,6 +18,7 @@ class COLDAnalysis(object) :
             on (str): column name in submission.submission dataframe to run analysis on
             plot (boolean): to plot results or not
             show_examples (boolean): to return examples or not
+            savePlotToFile (str): File name for saving plot, empty string will not save a plot
 
         Returns:
             plot_info (df) : results corresponding to plotted information:(total instances for each category,
@@ -36,7 +36,7 @@ class COLDAnalysis(object) :
          
          # plot the bar graph
         if plot:
-            plot_bar_graph(plot_info, title = str("Predictions on " + on),rot = rot)
+            plot_bar_graph(plot_info, savePlotToFile, title = str("Predictions on " + on),rot = rot)
          #get examples
         if show_examples:
             plot_info = get_examples(submission, on, plot_info)
@@ -46,7 +46,7 @@ class COLDAnalysis(object) :
         return plot_info, metrics
             
     @classmethod
-    def analyze_on(cls, submission:COLDSubmissionObject, on:str,plot=True,show_examples = False) : 
+    def analyze_on(cls, submission:DatasetSubmissionObject, on:str,plot=True,show_examples = False,savePlotToFile = "") : 
         """function for running analysis on a specific column, and plots results if specified. Returns two dataframes. 
             plot_info corresponds to information that is plotted, number of offensive/non offensive instances for each category 
             in "on" as well as
@@ -57,13 +57,14 @@ class COLDAnalysis(object) :
             on (str): column name in submission.submission dataframe to run analysis on
             plot (boolean): to plot results or not
             show_examples (boolean): to return examples or not
+            savePlotToFile (str): File name for saving plot, empty string will not save a plot
 
         Returns:
             plot_info (df) : results corresponding to plotted information:(total instances for each category,
                              total correctly predicted, and accuracy)
             metrics (df): classification report for each category
         """
-        return cls._run_analysis_on_functionality(submission, on, plot,show_examples)
+        return cls._run_analysis_on_functionality(submission, on, plot,show_examples,savePlotToFile)
 
         
 
