@@ -10,9 +10,12 @@ class COLD(Dataset) :
         self.dataset_name = 'Complex and Offensive Language Dataset'
         self.URL = 'COLD-team/COLD'
         self.description = 'This is the dataset from COLD.'
-        self.data_columns = ['ID', 'DataSet', 'Text']
+        
+        self.features = ['ID', 'DataSet', 'Text']
         self.label_columns = ['Off', 'Slur', 'Nom', 'Dist']
-        self.label_column = 'Off'
+        self.gold_column = 'Off'
+        self.text_column = 'Text'
+        
         self.unique_labels = None
         self.split = split
 
@@ -23,32 +26,9 @@ class COLD(Dataset) :
         return load_dataset(self.URL)[self.split].to_pandas()
 
     def submit(self, dataset: pd.DataFrame, submission: iter, map: dict = None) -> DatasetSubmissionObject:
-        submission_df = super().submit(dataset, submission, map)
-        return COLDSubmissionObject(submission_df)
+        return super().submit(dataset, submission, map)
 
 
-class COLDSubmissionObject(DatasetSubmissionObject) : 
-
-    label_column = 'Off'
-    prediction_column = 'preds'
-    text_column = 'Text'
-    data_columns = ['Text' , 'Off' , 'Nom' , 'Slur' , 'Dist']
-    
-    def __init__(self, submission: DatasetSubmissionObject):
-        self.submission = submission.submission
-
-    def filter_submission(self, on:str, filter:callable, **kwargs):
-
-        self.submission['filter_results'] = self.submission[on].apply(filter)
-        filtered_submission = self.submission[self.submission['filter_results'] == True]
-
-        if 'columns' in kwargs : 
-            outputs = [filtered_submission[col] for col in kwargs['columns']]
-            return outputs
-    
-        else : 
-            return [filtered_submission['Text'] , filtered_submission['Off'] , filtered_submission['preds']]
-
 
 
 if __name__ == '__main__' : 
