@@ -11,8 +11,11 @@ class HateXplain(Dataset) :
         self.dataset_name = 'HateXplain'
         self.URL = 'hatexplain'
         self.description = 'This is the dataset for HateXplain.'
-        self.data_columns = ['ID', 'post_tokens']
-        self.label_columns = ['label1' , 'label2' , 'label3']
+        
+        self.features = ['ID', 'post_tokens']
+        self.gold_column = ['label1' , 'label2' , 'label3']
+        self.text_column = 'post_tokens'
+       
         self.unique_labels = None
         self.split = split
 
@@ -42,30 +45,5 @@ class HateXplain(Dataset) :
 
 
     def submit(self, dataset: pd.DataFrame, submission: iter, map: dict = None) -> DatasetSubmissionObject:
-        submission_df = super().submit(dataset, submission, map)
-        return HateXplainSubmissionObject(submission_df)
+        return super().submit(dataset, submission, map)
 
-
-class HateXplainSubmissionObject(DatasetSubmissionObject) : 
-
-    def __init__(self, submission : DatasetSubmissionObject):
-        self.submission = submission.submission
-
-
-    def filter_submission(self, on:str, filter:callable, **kwargs):
-
-        self.submission['filter_results'] = self.submission[on].apply(filter)
-        filtered_submission = self.submission[self.submission['filter_results'] == True]
-
-        if 'columns' in kwargs : 
-            outputs = [filtered_submission[col] for col in kwargs['columns']]
-            return outputs
-    
-        else : 
-            return [filtered_submission['post_tokens'] , filtered_submission['label1'] , 
-                    filtered_submission['label2'] , filtered_submission['label3'] ,
-                    filtered_submission['preds']]
-
-
-
-    
\ No newline at end of file
